is_signature_only

Function is_signature_only 

fn is_signature_only<'gcx>(gcx: Gcx<'gcx>, cid: ContractId) -> bool
Returns true if cid is an “interface-like” abstract contract: signature-only and free of state, constructors, and modifier bodies. Such contracts mirror the role of interface and should be considered as candidate interfaces for the missing-inheritance check.